@@ -62,16 +62,16 @@ test_that("get data", {
   bb <- ghcnd(stationid = "AGE00135039")
   cc <- ghcnd(stationid = "ASN00008264")
 
-  expect_is(aa, "ghcnd")
-  expect_is(bb, "ghcnd")
-  expect_is(cc, "ghcnd")
+  expect_is(aa, "tbl_df")
+  expect_is(bb, "tbl_df")
+  expect_is(cc, "tbl_df")
 
-  expect_is(aa$data, "data.frame")
-  expect_is(bb$data, "data.frame")
-  expect_is(cc$data, "data.frame")
-  expect_is(aa$data$element, "character")
+  expect_is(aa, "data.frame")
+  expect_is(bb, "data.frame")
+  expect_is(cc, "data.frame")
+  expect_is(aa$element, "character")
 
-  expect_lt(NROW(cc$data), NROW(aa$data))
-  expect_lt(NROW(aa$data), NROW(bb$data))
-  expect_lt(NROW(cc$data), NROW(bb$data))
+  expect_lt(NROW(cc), NROW(aa))
+  expect_lt(NROW(aa), NROW(bb))
+  expect_lt(NROW(cc), NROW(bb))
 })
